package com.bwie.system.server.service.impl;

import java.util.List;

import com.bwie.system.common.domain.Emp;
import com.bwie.system.server.mapper.EmpMapper;
import com.bwie.system.server.service.IEmpService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 员工信息Service业务层处理
 *
 * @author bwie
 * @date 2024-01-12
 */
@Service
public class EmpServiceImpl implements IEmpService
{
    @Autowired
    private EmpMapper empMapper;

    /**
     * 查询员工信息
     *
     * @param empId 员工信息主键
     * @return 员工信息
     */
    @Override
    public Emp selectEmpByEmpId(Long empId)
    {
        return empMapper.selectEmpByEmpId(empId);
    }

    /**
     * 查询员工信息列表
     *
     * @param emp 员工信息
     * @return 员工信息
     */
    @Override
    public List<Emp> selectEmpList(Emp emp)
    {
        return empMapper.selectEmpList(emp);
    }

    /**
     * 新增员工信息
     *
     * @param emp 员工信息
     * @return 结果
     */
    @Override
    public int insertEmp(Emp emp)
    {
        return empMapper.insertEmp(emp);
    }

    /**
     * 修改员工信息
     *
     * @param emp 员工信息
     * @return 结果
     */
    @Override
    public int updateEmp(Emp emp)
    {
        return empMapper.updateEmp(emp);
    }

    /**
     * 批量删除员工信息
     *
     * @param empIds 需要删除的员工信息主键
     * @return 结果
     */
    @Override
    public int deleteEmpByEmpIds(Long[] empIds)
    {
        return empMapper.deleteEmpByEmpIds(empIds);
    }

    /**
     * 删除员工信息信息
     *
     * @param empId 员工信息主键
     * @return 结果
     */
    @Override
    public int deleteEmpByEmpId(Long empId)
    {
        return empMapper.deleteEmpByEmpId(empId);
    }
}
